function [freqs, tt, chans, nicknames]=getOscFrequencies(gpsSec, dur)
%% [freqs, tt, chans, nicknames]=getOscFrequencies(gpsSec, dur)
% gpsSec = gps time the frequencies that are fetched
% dur = duration in seconds
%
% freqs = list of frequencies (fetched if they're measured or defined in EPICS)
% tt = time vector starting gpsSec and ending gpsSec+dur
% chans = list of channels (defined and hardcoded in this function)
% nicknames = list of somewhat more descriptive names.

chans={'H1:IMC-VCO_FREQUENCY', ... % about 79MHz, same as H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_5
    'H1:ALS-C_DIFF_VCO_FREQUENCY',... % about 79MHz, same as H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_1
    'H1:ALS-C_COMM_VCO_FREQUENCY', ... % about 79MHz, same as H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_2
    'H1:ALS-X_VCO_FREQUENCY', ...
    'H1:ALS-Y_VCO_FREQUENCY', ...
    'H1:SQZ-FREQ_SQZVCO', ... %about 79MHz, same as H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_8
    'H1:SQZ-VCXO_FREQUENCY', ... % 203MHz SQZ VCXO, same as H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_9
    'H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_3', ...   % what's this? 40680000
    'H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_6', ...       % 9.1MHz OCXO
    'H1:SYS-TIMING_C_FO_A_PORT_11_SLAVE_CFC_FREQUENCY_7', ...   % what's this? ~158MHz, changes
    'H1:SYS-TIMING_C_FO_A_PORT_6_SLAVE_XOLOCK_MEASUREDFREQ', ...    % 21.5MHz OCXO
    'H1:SYS-TIMING_C_FO_A_PORT_7_SLAVE_XOLOCK_MEASUREDFREQ', ...    % 24MHz OCXO
    'H1:SYS-TIMING_C_FO_A_PORT_8_SLAVE_XOLOCK_MEASUREDFREQ', ...    % 35.5HMz OCXO
    'H1:SYS-TIMING_C_FO_A_PORT_9_SLAVE_XOLOCK_MEASUREDFREQ', ...    % 71MHz OCXO
    'H1:SYS-TIMING_C_FO_A_PORT_10_SLAVE_XOLOCK_MEASUREDFREQ'};      % 80MHz OCXO


nicknames={'IMC VCO 79M', ...
    'DIFF VCO 79M', ...
    'COMM VCO 79M', ...
    'ALS X VCO 79M', ...
    'ALS Y VCO 79M', ...
    'SQZ VCO 79M', ...
    'SQZ VCXO 203M', ...
    '40680000', ...
    '9.1MHz OCXO', ...
    '158MHz', ...
    '21.5MHz OCXO', ...
    '24MHz OCXO' , ...
    '35.5HMz OCXO', ...
    '71MHz OCXO' , ...
    '80MHz OCXO'};

gwd = GWData();
gwd.make_kerberos_ready;
gwd.site_info(2).port = 31200;
gwd.site_info(2).server = 'nds.ligo-wa.caltech.edu';
[freqs, tt, ~] = gwd.fetch(gpsSec, dur, chans);
return;